@@ -1,5 +1,5 @@
 package XML::Grammar::Screenplay::FromProto;
-$XML::Grammar::Screenplay::FromProto::VERSION = '0.22.1';
+$XML::Grammar::Screenplay::FromProto::VERSION = '0.22.2';
 use strict;
 use warnings;
 use autodie;
@@ -149,8 +149,12 @@ sub _handle_elem_of_name_a
 
     $self->_output_tag_with_childs(
         {
-            start => [ "ulink", "url" => $elem->lookup_attr("href") ],
-            elem  => $elem,
+            start => [
+                "a",
+                [ "http://www.w3.org/1999/xlink", "href" ],
+                $elem->lookup_attr("href"),
+            ],
+            elem => $elem,
         }
     );
 
@@ -257,7 +261,7 @@ Converts the file $path_to_file to XML and returns it.
 
 =head1 VERSION
 
-version 0.22.1
+version 0.22.2
 
 =for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
